<?php

namespace App\Http\Controllers;

use App\Http\Requests\UserStoreRequest;
use App\Http\Requests\UserUpdateRequest;
use App\User;
use App\deposit;
use App\investment_types;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;
use Spatie\Permission\Models\Role;
use PDF;
use Mail;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;





class UserController extends Controller
{
    public function __construct()
    {

        $this->middleware('permission:view-user')->except(['profile', 'profileUpdate']);
        $this->middleware('permission:create-user', ['only' => ['create','store']]);
        $this->middleware('permission:update-user', ['only' => ['edit','update']]);
        $this->middleware('permission:destroy-user', ['only' => ['destroy']]);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
       
        if ($request->has('search')) {
           // $users = User::where('name', 'like', '%'.$request->search.'%')->paginate(setting('record_per_page', 15));
        
           $users = DB::table('users')
            ->join('deposits', 'users.id', '=', 'deposits.user_id')
            ->join('investment_types', 'deposits.investment_id', '=', 'investment_types.id')
            ->select('users.*', 'deposits.amount','deposits.ondate', 'deposits.investment_id','investment_types.title')
            ->where('name', 'like', '%'.$request->search.'%')
            ->get();

        }elseif($request->has('plan')) {
            // $users = User::where('name', 'like', '%'.$request->search.'%')->paginate(setting('record_per_page', 15));
         
            if($request->plan == 'Personal'){
            $users = DB::table('users')
             ->join('deposits', 'users.id', '=', 'deposits.user_id')
             ->join('investment_types', 'deposits.investment_id', '=', 'investment_types.id')
             ->select('users.*', 'deposits.amount','deposits.ondate', 'deposits.investment_id','investment_types.title')
             ->where('deposits.investment_id', 1)
             ->get();
            }elseif($request->plan == 'Group'){

                $users = DB::table('users')
                ->join('deposits', 'users.id', '=', 'deposits.user_id')
                ->join('investment_types', 'deposits.investment_id', '=', 'investment_types.id')
                ->select('users.*', 'deposits.amount','deposits.ondate', 'deposits.investment_id','investment_types.title')
                ->where('deposits.investment_id', 2)
                ->get();

            }elseif($request->plan == 'Short-Long'){

                $users = DB::table('users')
                ->join('deposits', 'users.id', '=', 'deposits.user_id')
                ->join('investment_types', 'deposits.investment_id', '=', 'investment_types.id')
                ->select('users.*', 'deposits.amount','deposits.ondate', 'deposits.investment_id','investment_types.title')
                ->where('deposits.investment_id', 3)
                ->get();


            }
 
         }else{
            $users = DB::table('users')
            ->join('deposits', 'users.id', '=', 'deposits.user_id')
            ->join('investment_types', 'deposits.investment_id', '=', 'investment_types.id')
            ->select('users.*', 'deposits.amount','deposits.ondate', 'deposits.investment_id','investment_types.title')
            ->get();
            //$users= User::paginate(setting('record_per_page', 15));
           //  $users = User::with(['user','deposit'])->paginate(setting('record_per_page', 15));
        }
        $title =  'Manage Users';
        return view('users.index', compact('users','title'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $title = 'Create user';
        $investment_type = investment_types::pluck('title', 'id');
        $roles = Role::pluck('name', 'id');
        return view('users.create', compact('roles', 'title','investment_type'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(UserStoreRequest $request)
    {
       
        $userData = $request->except(['role', 'profile_photo']);
        if ($request->profile_photo) {
            $userData['profile_photo'] = parse_url($request->profile_photo, PHP_URL_PATH);
        }

        if($request->profit){

            $withdraw_amount = $request->profit + $request->amount;


        }else{

            $withdraw_amount =  $request->amount;
        }

        $startDate = 0;
        $endDate = 0;

        $user = User::create($userData);
        $user->assignRole($request->role);
        
        $investment_amount = $request->amount;
        $investment_id = $request->title;
        $ondate =  $request->ondate;

        $startDate = $request->startdate;
        $endDate = $request->enddate;
        
         


        $user_id = $user->id;

        $values = array('user_id' => $user_id,
        'amount' => $investment_amount, 
        'investment_id' => $investment_id,
        'category_id' => 2,
        'withdrawable' => $withdraw_amount, 
        'status' => 1,
        'endDate' => $endDate,
        'startDate' => $startDate,
        'ondate' => $ondate ,
        'created_at' =>  Carbon::now(),
        'updated_at' =>  Carbon::now() );

        $deposit = DB::table('deposits')->insert($values);
        
        flash('User created successfully!')->success();
        return redirect()->route('users.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function show(User $user)
    {
        $title = "User Details";
        $roles = Role::pluck('name', 'id');
       
        $deposit = DB::table('deposits')
             ->join('investment_types', 'deposits.investment_id', '=', 'investment_types.id')
             ->select( 'deposits.amount','deposits.ondate','investment_types.title','deposits.startDate','deposits.endDate')
             ->where('deposits.user_id', 'like', '%'.$user->id.'%')
             ->get();
       
        
        //return view('users.show', compact('user','title', 'roles'));

        // $amount = $deposit[0]->amount;
        // $plan = $deposit[0]->title;

      //  dd($deposit);   


        // share data to view
        if($deposit[0]->startDate == 0){
          
            $pdf = PDF::loadView('users.certificate', compact('user','title', 'roles','deposit'))->setPaper('a4', 'landscape');
  
            $data["email"] = $user->email;
            $data["title"] = "Hammad Traders | Personal Investment | Certificate";
            $data["body"] = "Welcome To Hammad Traders";
           
            return $pdf->download("certificate-HT-".$user->id.".pdf");
        }else{


            $pdf = PDF::loadView('users.certificate2', compact('user','title', 'roles','deposit'))->setPaper('a4', 'landscape');
  
            $data["email"] = $user->email;
            $data["title"] = "Hammad Traders | Personal Investment | Certificate";
            $data["body"] = "Welcome To Hammad Traders";
           
            return $pdf->download("certificate2-HT-".$user->id.".pdf");

        }
       
       


        // Mail::send('users.pdf', compact('user','title', 'roles'), function($message)use($data, $pdf) {
        //     $message->to($data["email"])
        //             ->subject($data["title"])
        //             ->attachData($pdf->output(), "certificate_x3.pdf");
        // });


        // download PDF file with download method
        
       // return view('users.show', compact('user','title', 'roles'));
                
    }

    

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function edit(User $user)
    {
        $title = "User Details";
        $roles = Role::pluck('name', 'id');
        $investment_type = investment_types::pluck('title', 'id');
        $deposit = deposit::where('user_id',$user->id)->first();
       // dd($deposit->investment_id);
        return view('users.edit', compact('user','title', 'roles','deposit','investment_type'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function update(UserUpdateRequest $request, User $user)
    {

        $userData = $request->except(['role', 'profile_photo','ondate','amount','title']);

        //dd($user->id);

        if ($request->profile_photo) {
            $userData['profile_photo'] = parse_url($request->profile_photo, PHP_URL_PATH);
        }
        $user->update($userData);
        $user->syncRoles($request->role);


        $update_data = deposit::where('user_id',$user->id)->first();

        $update_data->amount = $request->amount;
        $update_data->ondate = $request->ondate;
        $update_data->investment_id = $request->title;

        if($request->profit){

            $update_data->withdrawable = $request->profit;
        }

        $update_data->save();



        flash('User updated successfully!')->success();
        return redirect()->route('users.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\User  $user
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $user)
    {
        if ($user->id == Auth::user()->id || $user->id ==1) {
            flash('You can not delete logged in user!')->warning();
            return back();
        }
        $user->delete();
        flash('User deleted successfully!')->info();
        return back();

    }


    public function profile(User $user)
    {
        $title = 'Edit Profile';
        return view('users.profile', compact('title','user'));
    }
    public function profileUpdate(UserUpdateRequest $request, User $user)
    {
        $userData = $request->except('profile_photo');
        if ($request->profile_photo) {
            $userData['profile_photo'] = parse_url($request->profile_photo, PHP_URL_PATH);
        }

        $user->update($userData);
        flash('Profile updated successfully!')->success();
        return back();
    }
}
